<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ListDialog</name>
    <message>
        <location filename="listdialog.ui" line="17"/>
        <source>Please select an item</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="30"/>
        <source>Loudspeaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="36"/>
        <source>number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>vendor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="70"/>
        <source>model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="106"/>
        <source>Fs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="113"/>
        <location filename="mainwindow.ui" line="153"/>
        <location filename="mainwindow.ui" line="186"/>
        <location filename="mainwindow.ui" line="226"/>
        <location filename="mainwindow.ui" line="266"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <location filename="mainwindow.ui" line="470"/>
        <location filename="mainwindow.ui" line="780"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="146"/>
        <source>Qts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="179"/>
        <source>Vas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="193"/>
        <location filename="mainwindow.ui" line="349"/>
        <location filename="mainwindow.ui" line="433"/>
        <location filename="mainwindow.ui" line="686"/>
        <location filename="mainwindow.ui" line="743"/>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <source>Sd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="233"/>
        <source>m²</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="259"/>
        <source>Re</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="273"/>
        <source>Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="300"/>
        <source>Sealed enclosure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="303"/>
        <source>1st order filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="306"/>
        <source>Simple, safe enclosure good for several speakers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="332"/>
        <source>Enclosure volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="384"/>
        <source>Ported enclosure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="387"/>
        <source>2nd order filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="390"/>
        <source>Popular enclosure type to enhance bass for most speakers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="416"/>
        <source>Enclosure volume (Vb)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="453"/>
        <source>Enclosure filter resonance (Fb)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <location filename="mainwindow.ui" line="814"/>
        <source>Number of ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="521"/>
        <location filename="mainwindow.ui" line="831"/>
        <source>Port diameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <location filename="mainwindow.ui" line="585"/>
        <location filename="mainwindow.ui" line="625"/>
        <location filename="mainwindow.ui" line="845"/>
        <location filename="mainwindow.ui" line="885"/>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="555"/>
        <source>Slot port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="565"/>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="605"/>
        <location filename="mainwindow.ui" line="865"/>
        <source>Port length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="637"/>
        <source>Bandpass enclosure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="640"/>
        <source>4th order filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="643"/>
        <source>Enclosure for subwoofer, mostly used in 2:1, 5:1 and 7:1 systems.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="669"/>
        <source>Sealed enclosure volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="726"/>
        <source>Ported enclosure volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <source>Ported enclosure filter resonance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="910"/>
        <source>Project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="922"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="926"/>
        <source>Ported alignments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="939"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="945"/>
        <source>Speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="982"/>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="987"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="993"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1004"/>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1009"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1012"/>
        <source>Print the current project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1015"/>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1023"/>
        <source>Quit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1026"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1031"/>
        <location filename="mainwindow.cpp" line="580"/>
        <source>About QSpeakers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1034"/>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1039"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <source>New speaker parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1045"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1050"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1053"/>
        <source>Search a speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1058"/>
        <source>Optimize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1061"/>
        <source>Optimize frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1064"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1069"/>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1072"/>
        <source>Modify the current speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1075"/>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1080"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1083"/>
        <source>Remove the current speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1088"/>
        <source>Bessel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1091"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Linear phase and fast transient response alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1120"/>
        <source>Zbinden M4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1115"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Super boom box butterworth 4th order alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Moderate alignment (infinite baffle).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Moderate alignment for indoor (infinite baffle) application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1096"/>
        <source>Legendre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="976"/>
        <source>Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="979"/>
        <source>Open a speaker project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="990"/>
        <source>Save the current project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="998"/>
        <source>Save copy...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1001"/>
        <source>Save the current project in a copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1099"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Extended bass response with minimum ripple.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1104"/>
        <source>Hoge BB4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1107"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Boom box butterworth 4th order alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <oldsource>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Boom box butterworht 4th order alignment.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1112"/>
        <source>Bullock SBB4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="45"/>
        <source>Sealed volume frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="49"/>
        <source>Ported volume frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="53"/>
        <source>Bandpass volumes frequency response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="170"/>
        <source>Export File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="170"/>
        <source>/untitled.qsp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="170"/>
        <location filename="mainwindow.cpp" line="188"/>
        <source>QSpeakers project (*.qsp)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="180"/>
        <location filename="mainwindow.cpp" line="223"/>
        <source>Project not saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="181"/>
        <source>The current project has not been saved. Continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="188"/>
        <source>Import File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="224"/>
        <source>The current project has not been saved. Exit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="409"/>
        <source>Removal confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="410"/>
        <source>Do you really want to remove this loudspeaker from the database?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="581"/>
        <source>QSpeakers version </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="701"/>
        <location filename="mainwindow.cpp" line="726"/>
        <source>Unsaved speaker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="702"/>
        <location filename="mainwindow.cpp" line="727"/>
        <source>This speaker is not present in the database. Would you like to insert it before to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plot</name>
    <message>
        <location filename="plot.cpp" line="140"/>
        <source>Frequency [Hz]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="plot.cpp" line="152"/>
        <source>Sound pressure [dB]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="plot.cpp" line="161"/>
        <source>Peak: %1 dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="plot.cpp" line="172"/>
        <source>%1 dB at %2 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="bandpassbox.cpp" line="123"/>
        <source>Sealed Vol. %1 L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="124"/>
        <source>Ported Vol. %1 L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="125"/>
        <location filename="portedbox.cpp" line="174"/>
        <source>Port Diam. %1 cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="126"/>
        <location filename="portedbox.cpp" line="176"/>
        <source>Port Len. %1 cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="127"/>
        <location filename="portedbox.cpp" line="177"/>
        <source>Port Num. %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="bandpassbox.cpp" line="128"/>
        <location filename="portedbox.cpp" line="178"/>
        <source>Fb %1 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="portedbox.cpp" line="173"/>
        <location filename="sealedbox.cpp" line="51"/>
        <source>Vol. %1 L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="portedbox.cpp" line="175"/>
        <source>[Slot %1x%2 cm]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="system.cpp" line="78"/>
        <source>number of driver(s) is </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="searchdialog.ui" line="23"/>
        <source>Loudspeaker parameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchdialog.ui" line="36"/>
        <source>is between</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchdialog.ui" line="49"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpeakerDialog</name>
    <message>
        <location filename="speakerdialog.ui" line="22"/>
        <source>Vendor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="29"/>
        <source>speaker vendor name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="36"/>
        <source>Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="43"/>
        <source>speaker name or reference number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="50"/>
        <source>Fs (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="57"/>
        <source>Qts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="64"/>
        <source>Vas (L)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="71"/>
        <source>Sd (m²)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="108"/>
        <source>Re (Ohm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="speakerdialog.ui" line="118"/>
        <source>Xmax (mm)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
